@@ -37,7 +37,7 @@ enum {
     TOKEN_FG,
     TOKEN_BG,
     TOKEN_BASE,
-    TOKEN_TEXT
+    TOKEN_TEXT,
 };
 
 static struct symbol_struct theme_symbols[] = {
@@ -145,7 +145,7 @@ static struct symbol_struct theme_symbols[] = {
     { "SPIN_ARROW_DOWN", EAZEL_ENGINE_SPIN_ARROW_DOWN },				\
     { 0, 0 }
 
-/* static struct symbol_struct theme_symbols[] = { THEME_SYMBOLS }; */
+//static struct symbol_struct theme_symbols[] = { THEME_SYMBOLS };
 
 static guint n_theme_symbols = (sizeof(theme_symbols) / sizeof(theme_symbols[0])) - 1;
 
@@ -222,13 +222,13 @@ stock_index (const char *symbol)
 }
 
 void
-crux_theme_data_ref (eazel_theme_data *theme_data)
+theme_data_ref (eazel_theme_data *theme_data)
 {
     theme_data->refcount++;
 }
 
 void
-crux_theme_data_unref (eazel_theme_data *theme_data)
+theme_data_unref (eazel_theme_data *theme_data)
 {
     theme_data->refcount--;
     if (theme_data->refcount == 0)
@@ -989,9 +989,9 @@ crux_parse_rc_style  (GtkRcStyle   *rc_style,
 	   a very useful one! */
 
 	if (default_theme_data != 0)
-	    crux_theme_data_unref (default_theme_data);
+	    theme_data_unref (default_theme_data);
 
-	crux_theme_data_ref (theme_data);
+	theme_data_ref (theme_data);
 	default_theme_data = theme_data;
     }
 
