@@ -18,7 +18,6 @@
 #include "industrial_style_versioned_include.h"
 #include <string.h>
 #include <stdlib.h>
-#include <ctype.h>
 
 #define DETAIL(xx)   ((detail) && (!strcmp((xx), detail)))
 #if INDUSTRIAL_GTK_VERSION == 2
@@ -529,11 +528,13 @@ ensure_pixmap (GtkStyle *style, GdkWindow *window, Shading *shading, int pixmap)
     char **xpm_copy;
     int colors;
     int height;
+    int width;
     int i;
 
     xpm = pixmaps[pixmap];
     first_line = g_strsplit (xpm[0], " ", 0);
 
+    width = atoi (first_line[0]);
     height = atoi (first_line[1]);
     colors = atoi (first_line[2]);
 
@@ -596,6 +597,18 @@ get_color (GtkStyle *style, GdkColor *bg_color, GdkColor *fg_color, int shade)
   return &shading->colors[shade];
 }
 
+static GdkGC *
+get_gray_gc (GtkStyle *style, int shade)
+{
+  return get_gc (style, &style->bg[GTK_STATE_NORMAL], &style->fg[GTK_STATE_NORMAL], shade);
+}
+
+static GdkColor *
+get_gray_color (GtkStyle *style, int shade)
+{
+  return get_color (style, &style->bg[GTK_STATE_NORMAL], &style->fg[GTK_STATE_NORMAL], shade);
+}
+
 static gboolean 
 sanitize_size (GdkWindow      *window,
 	       gint           *width,
@@ -891,6 +904,28 @@ draw_rounded_rect_two_pixel (GdkWindow *window,
   kaleidoscope_point (window, corner_gc, area, x, y, width, height, 0, 1);
 }
 
+static void
+draw_dot (GdkWindow *window,
+	  GdkGC *gc,
+	  GtkOrientation orientation,
+	  int x_base,
+	  int y_base,
+	  int first_offset,
+	  int second_offset)
+{
+  if (orientation == GTK_ORIENTATION_HORIZONTAL) {
+    gdk_draw_point (window,
+		    gc,
+		    x_base + first_offset,
+		    y_base + second_offset);
+  } else {
+    gdk_draw_point (window,
+		    gc,
+		    x_base + second_offset,
+		    y_base + first_offset);
+  }
+}
+
   /* #define names assume vertical */
 #define HANDLE_HEIGHT (4 * 4 + 1 + 2)
 #define HANDLE_WIDTH (4 + 1 + 2)
@@ -977,7 +1012,7 @@ draw_hline (GtkStyle     *style,
 {
   GdkGC *gc;
   
-#ifdef DEBUG
+#if DEBUG
   printf ("draw_hline: %p %p %s %i %i %i\n", widget, window, detail, x1, x2,
 	  y);
 #endif
@@ -1040,7 +1075,7 @@ draw_handle (GtkStyle      *style,
   
   sanitize_size (window, &width, &height);
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, orientation);
 #endif
@@ -1125,7 +1160,7 @@ draw_vline (GtkStyle     *style,
 {
   GdkGC *gc;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i\n", __FUNCTION__, widget, window, detail, y1, y2,
 	  x);
 #endif
@@ -1163,7 +1198,7 @@ draw_slider (GtkStyle      *style,
 {
   int handle_width, handle_height;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, orientation);
 #endif
@@ -1306,6 +1341,7 @@ real_draw_box (GtkStyle      *style,
 
     GdkGC *gc;
     GdkColor *color;
+    int gradient_lines = 7;
 
     if (! (GTK_WIDGET_HAS_DEFAULT (widget) &&
 	   GTK_IS_BUTTON (widget) && 
@@ -1672,9 +1708,10 @@ real_draw_box (GtkStyle      *style,
 	bg_color = get_color (style, &style->bg[state_type], &style->fg[state_type], SHADE_BG);
 	corner_gc = get_gc (style, bg_color, fg_color, SHADE_HALF);
       }
-      draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc,
-				   area, x, y, width, height);
     }
+
+    draw_rounded_rect_one_pixel (window, bg_gc, fg_gc, corner_gc,
+				 area, x, y, width, height);
   } else if (DETAIL("menubar")) {
     GdkGC *bg_gc;
     GdkGC *fg_gc;
@@ -1797,7 +1834,7 @@ draw_box (GtkStyle      *style,
 	  gint           width,
 	  gint           height)
 {
-#ifdef DEBUG
+#if DEBUG
   printf ("draw_box: %p %p %s %i %i %i %i\n", widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -1828,7 +1865,7 @@ draw_shadow (GtkStyle        *style,
 	     gint             width,
 	     gint             height)
 {
-#ifdef DEBUG
+#if DEBUG
   printf ("draw_shadow: %p %p %s %i %i %i %i\n", widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -1935,7 +1972,7 @@ draw_box_gap (GtkStyle       *style,
 	      gint            gap_x,
 	      gint            gap_width)
 {
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -1992,7 +2029,7 @@ draw_shadow_gap (GtkStyle       *style,
 		 gint            gap_x,
 		 gint            gap_width)
 {
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -2024,7 +2061,7 @@ draw_extension (GtkStyle       *style,
   GdkColor *fg_color;
   GdkGC *corner_gc;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i  %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height, gap_side);
 #endif
@@ -2235,7 +2272,7 @@ draw_arrow (GtkStyle      *style,
 {
   gint original_width, original_x;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2314,7 +2351,7 @@ draw_check (GtkStyle		*style,
 
   GdkColor *fg, *bg;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2344,11 +2381,20 @@ draw_check (GtkStyle		*style,
 
   gdk_window_get_size (pixmap, &src_width, &src_height);
 
+  if (width >= src_width) {
+    x = x + (width - src_width) / 2;
+    width = src_width;
+  }
+  if (height >= src_height) {
+    y = y + (height - src_height) / 2;
+    height = src_height;
+  }
+
   if (area)
     gdk_gc_set_clip_rectangle (gc, area);
   gdk_gc_set_clip_mask (gc, get_mask (style, window, bg, fg, which + decode_shadow (shadow_type)));
   gdk_gc_set_clip_origin (gc, x, y);
-  gdk_draw_pixmap (window, gc, pixmap, 0, 0, x, y, MIN (width, src_width), MIN (height, src_height));
+  gdk_draw_pixmap (window, gc, pixmap, 0, 0, x, y, width, height);
   gdk_gc_set_clip_mask (gc, NULL);
   gdk_gc_set_clip_origin (gc, 0, 0);
   if (area)
@@ -2374,7 +2420,7 @@ draw_option (GtkStyle		*style,
   int which;
   GdkColor *fg, *bg;
 
-#ifdef DEBUG
+#if DEBUG
   printf ("%s: %p %p %s %i %i %i %i\n", __FUNCTION__, widget, window, detail, x, y,
 	  width, height);
 #endif
@@ -2402,11 +2448,20 @@ draw_option (GtkStyle		*style,
 
   gdk_window_get_size (pixmap, &src_width, &src_height);
 
+  if (width >= src_width) {
+    x = x + (width - src_width) / 2;
+    width = src_width;
+  }
+  if (height >= src_height) {
+    y = y + (height - src_height) / 2;
+    height = src_height;
+  }
+  
   if (area)
     gdk_gc_set_clip_rectangle (gc, area);
   gdk_gc_set_clip_mask (gc, get_mask (style, window, bg, fg, which + decode_shadow (shadow_type)));
   gdk_gc_set_clip_origin (gc, x, y);
-  gdk_draw_pixmap (window, gc, pixmap, 0, 0, x, y, MIN (width, src_width), MIN (height, src_height));
+  gdk_draw_pixmap (window, gc, pixmap, 0, 0, x, y, width, height);
   gdk_gc_set_clip_mask (gc, NULL);
   gdk_gc_set_clip_origin (gc, 0, 0);
   if (area)
