@@ -1147,9 +1147,8 @@ draw_box(GtkStyle * style,
          gint height)
 {
   GdkGC *light_gc, *dark_gc;
-#ifdef DEBUG
   GtkOrientation      orientation;
-#endif
+
   g_return_if_fail(style != NULL);
   g_return_if_fail(window != NULL);
 
@@ -1158,11 +1157,11 @@ draw_box(GtkStyle * style,
   light_gc = style->light_gc[state_type];
   dark_gc = style->dark_gc[state_type];
 
-#ifdef DEBUG
   orientation = GTK_ORIENTATION_HORIZONTAL;
   if (height > width)
     orientation = GTK_ORIENTATION_VERTICAL;
 
+#ifdef DEBUG
   printf("%p %s %i %i state_type = %d (%d)\n", detail, detail, width, height, state_type, orientation);
 #endif
 
@@ -1180,7 +1179,8 @@ draw_box(GtkStyle * style,
           gdk_gc_set_clip_rectangle(light_gc, area);
           gdk_gc_set_clip_rectangle(dark_gc, area);
 
-#ifdef DEBUG 
+#if 0
+          /* DEBUG */
           points[0].x = x ;
           points[0].y = y ;
           points[1].x = x + width;
@@ -1191,6 +1191,7 @@ draw_box(GtkStyle * style,
           points[3].y = y + height;
 
           gdk_draw_polygon(window, light_gc, FALSE, points, 4);
+          /* DEBUG */
 #endif
 
           if (size % 2)
@@ -1269,7 +1270,7 @@ draw_box(GtkStyle * style,
         }
       /* Paint a triangle here instead of in "buttondefault"
          which is drawn _behind_ the current button */
-      if (widget && GTK_WIDGET_HAS_DEFAULT (widget))
+      if (GTK_WIDGET_HAS_DEFAULT (widget))
         {
           gdk_draw_polygon(window, dark_gc,
                            FALSE, points1, 3);
@@ -2040,7 +2041,7 @@ draw_handle(GtkStyle * style,
 {
   GdkGC              *light_gc, *dark_gc;
   GdkRectangle        dest;
-  /* ThemeStyleData     *data = NULL;//style->engine_data; */
+//  ThemeStyleData     *data = NULL;//style->engine_data;
   gint                modx, mody;
 
   g_return_if_fail(style != NULL);
@@ -2054,7 +2055,7 @@ draw_handle(GtkStyle * style,
 
   if (DETAIL("paned")) 
     {
-      int i, w;
+      int i, w, h;
       int start_i, end_i;
 
       dest.x = x;
